---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Problematic file**
If the problem only occurs with a specific CRD or LST file, please attach the file to the issue.

**Package:**
 - What version of the `rimseval` package are you using?
 - What python environment are you running your evaluation scripts from? [Jupyter, iPython, ...]
 - What operating system are you working with?

**Desktop / GUI (please complete the following information):**
 - OS: [e.g. Windows]
 - Version [displayed on the top of the Main Window]
 - How did you install the GUI? [Installer, Anaconda, Python, ...]

**Additional context**
Add any other context about the problem here.
